.. src documentation master file, created by
   sphinx-quickstart on Thu Nov  9 10:09:14 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to src's documentation!
===============================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   PyFemtet


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
